@@ -278,6 +278,14 @@ class SupplyCurveConfig(AnalysisConfig):
         This determines the ordering of the buildout algorithm."""
         return self.get('sort_on', self._default_sort_on)
 
+    @property
+    def offshore_trans_table(self):
+        """
+        Get path to .csv containing offshore transmission table. If None,
+        exclude offshore supply curve points
+        """
+        return self.get('offshore_trans_table', None)
+
     @property
     def wind_dirs(self):
         """Get the supply curve power-rose wind directions"""
@@ -293,6 +301,13 @@ class SupplyCurveConfig(AnalysisConfig):
         """Get the flag to exclude downwind as well as upwind sites"""
         return self.get('downwind', False)
 
+    @property
+    def offshore_compete(self):
+        """
+        Get flag to execute competitive wind directions for offshore sites
+        """
+        return self.get('offshore_compete', False)
+
     @property
     def max_workers(self):
         """Get the number of workers to use during computation"""
